package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcBzhan;
import org.apache.ibatis.annotations.Param;

/**
 * B站、小红书Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcBzhanMapper 
{
    /**
     * 查询B站、小红书
     * 
     * @param id B站、小红书主键
     * @return B站、小红书
     */
    public TcBzhan selectTcBzhanById(Long id);

    /**
     * 查询B站、小红书列表
     * 
     * @param tcBzhan B站、小红书
     * @return B站、小红书集合
     */
    public List<TcBzhan> selectTcBzhanList(TcBzhan tcBzhan);

    /**
     * 新增B站、小红书
     * 
     * @param tcBzhan B站、小红书
     * @return 结果
     */
    public int insertTcBzhan(TcBzhan tcBzhan);

    /**
     * 修改B站、小红书
     * 
     * @param tcBzhan B站、小红书
     * @return 结果
     */
    public int updateTcBzhan(TcBzhan tcBzhan);

    /**
     * 删除B站、小红书
     * 
     * @param id B站、小红书主键
     * @return 结果
     */
    public int deleteTcBzhanById(Long id);

    /**
     * 批量删除B站、小红书
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcBzhanByIds(Long[] ids);
    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
