package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcBmtb;
import com.ruoyi.tcZz.domain.TcBzhan;
import com.ruoyi.tcZz.domain.TcWljg;
import com.ruoyi.tcZz.service.ITcBzhanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * B站、小红书Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "B站、小红书")
@RequestMapping("/tcZz/netManage/bzhan")
public class TcBzhanController extends BaseController {
    @Autowired
    private ITcBzhanService tcBzhanService;

    /**
     * 查询B站、小红书列表
     */
    @ApiOperation(value = "查询B站、小红书列表", response = TcBzhan.class)
    @GetMapping("/list")
    public TableDataInfo list(TcBzhan tcBzhan) {
        startPage();
        List<TcBzhan> list = tcBzhanService.selectTcBzhanList(tcBzhan);
        return getDataTable(list);
    }

    /**
     * 导出B站、小红书列表
     */
    @ApiOperation(value = "出B站、小红书列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcBzhan tcBzhan) {
        List<TcBzhan> list = tcBzhanService.selectTcBzhanList(tcBzhan);
        ExcelUtil<TcBzhan> util = new ExcelUtil<TcBzhan>(TcBzhan.class);
        util.exportExcel(response, list, "B站、小红书数据");
    }

    /**
     * 获取B站、小红书详细信息
     */
    @ApiOperation(value = "获取B站、小红书详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcBzhanService.selectTcBzhanById(id));
    }

    /**
     * 新增B站、小红书
     */
    @ApiOperation(value = "新增B站、小红书")
    @PostMapping
    public AjaxResult add(@RequestBody TcBzhan tcBzhan) {
        return toAjax(tcBzhanService.insertTcBzhan(tcBzhan));
    }

    /**
     * 修改B站、小红书
     */
    @ApiOperation(value = "修改B站、小红书")
    @PutMapping
    public AjaxResult edit(@RequestBody TcBzhan tcBzhan) {
        return toAjax(tcBzhanService.updateTcBzhan(tcBzhan));
    }

    /**
     * 删除B站、小红书
     */
    @ApiOperation(value = "删除B站、小红书")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcBzhanService.deleteTcBzhanByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcBzhan> util = new ExcelUtil<TcBzhan>(TcBzhan.class);
        List<TcBzhan> tcBzhanList = util.importExcel(file.getInputStream());
        tcBzhanService.importUser(tcBzhanList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcBzhanService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcBzhan> util = new ExcelUtil<TcBzhan>(TcBzhan.class);
        util.importTemplateExcel(response, " B站、小红书");
    }
}
